@@ -28,6 +28,7 @@ class PipeType(Enum):
     FLOAT_SHOE = "Float Shoe"
     CROSS_OVER = "Cross Over"
     TOE_SLEEVE = "Toe Sleeve"
+    CASING_JOINTS = "Casing Joints"
 
     @staticmethod
     def determine_type(family: str):
@@ -46,7 +47,8 @@ class PipeType(Enum):
             'float_collar': PipeType.FLOAT_COLLAR,
             'float_shoe': PipeType.FLOAT_SHOE,
             'cross_over': PipeType.CROSS_OVER,
-            'toe_sleeve': PipeType.TOE_SLEEVE
+            'toe_sleeve': PipeType.TOE_SLEEVE,
+            'casing_joints': PipeType.CASING_JOINTS
         }
         _type = mapping.get(family)
         if not _type:
